@@ -32,4 +32,7 @@ JSONRPC_SERVER_ERROR_TEXT = 'Server error'
 
 
 def is_http_client_error(code):
+    """Returns true if a status code is a 4xx Client Error.
+    See http://en.wikipedia.org/wiki/List_of_HTTP_status_codes#4xx_Client_Error
+    """
     return 400 <= code <= 499
